@@ -160,6 +160,8 @@ class DatabaseConnection:
             traceback.print_exception(type(e), e, e.__traceback__)
             logger.error(f"#       Stack:")
             traceback.print_stack()
+            logger.error(f"#       Using data:")
+            logger.error(pprint.pformat(data))
             logger.error(f"#######################################")
             logger.error("")
             logger.error("")
