@@ -11,7 +11,7 @@ class DatabaseCheck:
         self.config = config
         self.dbc = DatabaseConnection.get_connection(self.config)
         assert self.dbc.is_ok()
-#        self.create_tables()
+        self.create_tables()
 
     def create_tables(self):
         # Create a table to keep track of test items
@@ -76,7 +76,8 @@ class DatabaseCheck:
 
     def verify(self):
         try:
-            now=selfget_now()
+            now=self.get_now()
+            return True
         except Exception as e:
             logger.warning(f"Unknown error '{e}':", exc_info=True)
             return False
